@@ -1,5 +1,6 @@
 import configparser
 import json
+import pathlib
 import typing
 
 import httpx
@@ -132,6 +133,28 @@ def remove_config(
     return ctx.obj.config
 
 
+def get_file_location(filepath: str) -> pathlib.Path:
+    fp = pathlib.Path(filepath)
+    if not fp.exists():
+        send_output(
+            msg="Can not find file: {}".format(fp),
+            exit_code=1,
+        )
+    return fp
+
+
+def load_json_file(fp: pathlib.Path, content_type: str) -> typing.Union[typing.Dict, typing.List]:
+    with fp.open() as f:
+        try:
+            data = json.load(f)
+        except json.decoder.JSONDecodeError:
+            send_output(
+                msg="Invalid {} file, must be json format.".format(content_type),
+                exit_code=1,
+            )
+    return data
+
+
 def _request(ctx: typer.Context, method: str, url: str, **kwargs):
     return httpx.request(method=method, url=url, headers=bearer(ctx), verify=not ctx.obj.profile.ignore_tls, **kwargs)
 
